==> scummvm_2.1.1+dfsg1.orig.tar.xz: scummvm-2.1.1/engines/mutationofjb/commands/switchpartcommand.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef MUTATIONOFJB_SWITCHPARTCOMMAND_H
#define MUTATIONOFJB_SWITCHPARTCOMMAND_H

#include "mutationofjb/commands/seqcommand.h"
#include "common/scummsys.h"

namespace MutationOfJB {

class ConversationTask;

class SwitchPartCommandParser : public SeqCommandParser {
public:
	virtual bool parse(const Common::String &line, ScriptParseContext &parseCtx, Command *&command) override;
};

class SwitchPartCommand : public SeqCommand {
public:
	SwitchPartCommand() {}
	virtual ExecuteResult execute(ScriptExecutionContext &scriptExecCtx) override;
	virtual Common::String debugString() const override;
};

}

#endif

==> scummvm_2.2.0+dfsg1.orig.tar.xz: scummvm-2.2.0/engines/mutationofjb/commands/switchpartcommand.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef MUTATIONOFJB_SWITCHPARTCOMMAND_H
#define MUTATIONOFJB_SWITCHPARTCOMMAND_H

#include "mutationofjb/commands/seqcommand.h"
#include "common/scummsys.h"

namespace MutationOfJB {

class ConversationTask;

class SwitchPartCommandParser : public SeqCommandParser {
public:
	bool parse(const Common::String &line, ScriptParseContext &parseCtx, Command *&command) override;
};

class SwitchPartCommand : public SeqCommand {
public:
	SwitchPartCommand() {}
	ExecuteResult execute(ScriptExecutionContext &scriptExecCtx) override;
	Common::String debugString() const override;
};

}

#endif
